searchNodes=[{"ref":"Arangox.html","title":"Arangox","type":"module","doc":"An implementation of db_connection for ArangoDB, which is silly because ArangoDB is not a transactional database (i.e. no prepare, commit, rollback, etc.), but whatever, it&#39;s a solid connection pooler. Tested on: ArangoDB 3.3.9 - 3.5 Elixir 1.6 - 1.9 OTP 20 - 22 Supports active failover. Peer Dependencies Arangox requires a json library and http client to work, the defaults are :jason and :gun: def deps do [ ... {:arangox, &quot;~&gt; 0.1.0&quot;}, {:jason, &quot;~&gt; 1.1&quot;}, {:gun, &quot;~&gt; 1.3&quot;} ] end You might need to add :gun as an extra application in mix.exs: def application() do [ extra_applications: [:logger, :gun]) ] end To use a different json library, set the :json_library config to the module of your choice: config :arangox, :json_library, Poison Arangox already has a Mint client. To use it, add :mint to your deps instead of :gun and set the :client start option to Arangox.Client.Mint: Arangox.start_link(client: Arangox.Client.Mint) NOTE: Mint does not accept paths to unix sockets at the moment. To use something else, you&#39;d have to implement the Arangox.Client behaviour in a module somewhere and set that instead. The Arangox.Endpoint module has utilities for parsing ArangoDB endpoints. Examples iex&gt; {:ok, conn} = Arangox.start_link(pool_size: 10) iex&gt; Arangox.request(conn, :options, &quot;/&quot;) {:ok, %Arangox.Request{ body: &quot;&quot;, headers: [{&quot;authorization&quot;, &quot;...&quot;}], method: :options, path: &quot;/&quot; }, %Arangox.Response{ body: nil, headers: [ {&quot;x-content-type-options&quot;, &quot;nosniff&quot;}, {&quot;allow&quot;, &quot;DELETE, GET, HEAD, OPTIONS, PATCH, POST, PUT&quot;}, {&quot;server&quot;, &quot;ArangoDB&quot;}, {&quot;connection&quot;, &quot;Keep-Alive&quot;}, {&quot;content-type&quot;, &quot;text/plain; charset=utf-8&quot;}, {&quot;content-length&quot;, &quot;0&quot;} ], status: 200 }} iex&gt; Arangox.options!(conn) %Arangox.Response{ body: nil, headers: [ {&quot;x-content-type-options&quot;, &quot;nosniff&quot;}, {&quot;allow&quot;, &quot;DELETE, GET, HEAD, OPTIONS, PATCH, POST, PUT&quot;}, {&quot;server&quot;, &quot;ArangoDB&quot;}, {&quot;connection&quot;, &quot;Keep-Alive&quot;}, {&quot;content-type&quot;, &quot;text/plain; charset=utf-8&quot;}, {&quot;content-length&quot;, &quot;0&quot;} ], status: 200 } Options Arangox assumes defaults for the :endpoints, :username and :password options, and db_connection assumes a default :pool_size of 1 so the following: Arangox.start_link() Is equivalent to: options = [ pool_size: 1, endpoints: [&quot;http://localhost:8529&quot;], username: &quot;root&quot;, password: &quot;&quot; ] Arangox.start_link(options) Endpoints See the arangosh or arangojs documentation for examples of supported endpoint formats. As is common amongst ArangoDB drivers, arangox takes a list of endpoints as binaries: endpoints = [ &quot;http://localhost:8529&quot;, &quot;http://localhost:8530&quot;, &quot;http://localhost:8531&quot; ] Arangox.start_link(endpoints: endpoints) Arangox will try to establish a connection with the first endpoint it can and check it&#39;s availability (via the ArangoDB api). If an endpoint is in maintenance mode or is a follower in an active failover setup, it will be skipped. With the read_only? option set to true, arangox will try to find a server in readonly mode instead and add the x-arango-allow-dirty-read header to every request: iex&gt; endpoints = [&quot;http://localhost:8003&quot;, &quot;http://localhost:8004&quot;, &quot;http://localhost:8005&quot;] iex&gt; {:ok, conn} = Arangox.start_link(endpoints: endpoints, read_only?: true) iex&gt; %Arangox.Response{body: body} = Arangox.get!(conn, &quot;/_admin/server/mode&quot;) iex&gt; body[&quot;mode&quot;] &quot;readonly&quot; iex&gt; {:error, exception} = Arangox.post(conn, &quot;/_api/database&quot;, %{name: &quot;newDatabase&quot;}) iex&gt; exception.message &quot;forbidden&quot; Authentication Arangox will generate an authorization header with the :username and :password options and add it to every request. To prevent this behavior, set the :auth? option to false. iex&gt; {:ok, conn} = Arangox.start_link(auth?: false) iex&gt; {:error, exception} = Arangox.get(conn, &quot;/_admin/server/mode&quot;) iex&gt; exception.message &quot;not authorized to execute this request&quot; The header value is obfuscated in transfomed requests returned by arangox, for obvious reasons: iex&gt; {:ok, conn} = Arangox.start_link() iex&gt; {:ok, request, _response} = Arangox.options(conn) iex&gt; request.headers [{&quot;authorization&quot;, &quot;...&quot;}] Databases If a value is given to the :database option, arangox will prepend /_db/:value to the path of every request that isn&#39;t already prepended. If a value is not given, nothing is prepended (ArangoDB will assume the _system database). iex&gt; {:ok, conn} = Arangox.start_link() iex&gt; {:ok, request, _response} = Arangox.get(conn, &quot;/_admin/time&quot;) iex&gt; request.path &quot;/_admin/time&quot; iex&gt; {:ok, conn} = Arangox.start_link(database: &quot;myDatabase&quot;) iex&gt; {:ok, request, _response} = Arangox.get(conn, &quot;/_admin/time&quot;) iex&gt; request.path &quot;/_db/myDatabase/_admin/time&quot; iex&gt; {:ok, request, _response} = Arangox.get(conn, &quot;/_db/anotherDatabase/_admin/time&quot;) iex&gt; request.path &quot;/_db/anotherDatabase/_admin/time&quot; Headers Headers are given as lists of two-element tuples: [{&quot;header&quot;, &quot;value&quot;}, {&quot;another-header&quot;, &quot;another-value&quot;}] When given to the start option they are merged with every request. iex&gt; {:ok, conn} = Arangox.start_link(headers: [{&quot;header&quot;, &quot;value&quot;}]) iex&gt; {:ok, request, _response} = Arangox.options(conn) iex&gt; request.headers [{&quot;authorization&quot;, &quot;...&quot;}, {&quot;header&quot;, &quot;value&quot;}] Headers can also be passed as an argument to any request: iex&gt; {:ok, conn} = Arangox.start_link() iex&gt; {:ok, request, _response} = Arangox.get(conn, &quot;/_admin/time&quot;, [{&quot;header&quot;, &quot;value&quot;}]) iex&gt; request.headers [{&quot;header&quot;, &quot;value&quot;}, {&quot;authorization&quot;, &quot;...&quot;}] Headers given to the start option will not override any of the headers set by Arangox, but headers passed to requests will. Transport Transport options can be specified via :tcp_opts and :ssl_opts, for non-encrypted and encrypted connections respectively. These options are passed directly to the :transport_opts option of :gun or Mint. See :gen_tcp.connect_option() for more information on :tcp_opts, or :ssl.tls_client_option() for :ssl_opts. The :client_opts option can be used to pass client-specific options to :gun or Mint. These options are merged with and may override values set by arangox. Some options cannot be overridden (i.e. Mint&#39;s :mode option). If :transport_opts is set here it will override everything given to :tcp_opts or :ssl_opts, regardless of whether or not a connection is encrypted. See the gun:opts() type in the gun docs or connect/4 in the mint docs for more information. Contributing mix do format, credo docker-compose up -d mix test Roadmap A VelocyStream client An Ecto adapter More descriptive logs If anyone would like to collaborate, find me on the elixir-lang or arangodb-community slack."},{"ref":"Arangox.html#child_spec/1","title":"Arangox.child_spec/1","type":"function","doc":"Returns a supervisor child specification for a DBConnection pool."},{"ref":"Arangox.html#delete/4","title":"Arangox.delete/4","type":"function","doc":"Runs a DELETE request against a connection pool. Accepts any of the options accepted by DBConnection.execute/4."},{"ref":"Arangox.html#delete!/4","title":"Arangox.delete!/4","type":"function","doc":"Runs a DELETE request against a connection pool. Raises in the case of an error. Accepts any of the options accepted by DBConnection.execute!/4."},{"ref":"Arangox.html#get/4","title":"Arangox.get/4","type":"function","doc":"Runs a GET request against a connection pool. Accepts any of the options accepted by DBConnection.execute/4."},{"ref":"Arangox.html#get!/4","title":"Arangox.get!/4","type":"function","doc":"Runs a GET request against a connection pool. Raises in the case of an error. Accepts any of the options accepted by DBConnection.execute!/4."},{"ref":"Arangox.html#head/4","title":"Arangox.head/4","type":"function","doc":"Runs a HEAD request against a connection pool. Accepts any of the options accepted by DBConnection.execute/4."},{"ref":"Arangox.html#head!/4","title":"Arangox.head!/4","type":"function","doc":"Runs a HEAD request against a connection pool. Raises in the case of an error. Accepts any of the options accepted by DBConnection.execute!/4."},{"ref":"Arangox.html#json_library/0","title":"Arangox.json_library/0","type":"function","doc":"Returns the configured JSON library. To customize the JSON library, include the following in your config/config.exs: config :arangox, :json_library, Module Defaults to Jason."},{"ref":"Arangox.html#options/2","title":"Arangox.options/2","type":"function","doc":"Runs a OPTIONS request against a connection pool. Accepts any of the options accepted by DBConnection.execute/4."},{"ref":"Arangox.html#options!/2","title":"Arangox.options!/2","type":"function","doc":"Runs a OPTIONS request against a connection pool. Raises in the case of an error. Accepts any of the options accepted by DBConnection.execute!/4."},{"ref":"Arangox.html#patch/5","title":"Arangox.patch/5","type":"function","doc":"Runs a PATCH request against a connection pool. Accepts any of the options accepted by DBConnection.execute/4."},{"ref":"Arangox.html#patch!/5","title":"Arangox.patch!/5","type":"function","doc":"Runs a PATCH request against a connection pool. Raises in the case of an error. Accepts any of the options accepted by DBConnection.execute!/4."},{"ref":"Arangox.html#post/5","title":"Arangox.post/5","type":"function","doc":"Runs a POST request against a connection pool. Accepts any of the options accepted by DBConnection.execute/4."},{"ref":"Arangox.html#post!/5","title":"Arangox.post!/5","type":"function","doc":"Runs a POST request against a connection pool. Raises in the case of an error. Accepts any of the options accepted by DBConnection.execute!/4."},{"ref":"Arangox.html#put/5","title":"Arangox.put/5","type":"function","doc":"Runs a PUT request against a connection pool. Accepts any of the options accepted by DBConnection.execute/4."},{"ref":"Arangox.html#put!/5","title":"Arangox.put!/5","type":"function","doc":"Runs a PUT request against a connection pool. Raises in the case of an error. Accepts any of the options accepted by DBConnection.execute!/4."},{"ref":"Arangox.html#request/6","title":"Arangox.request/6","type":"function","doc":"Runs a request against a connection pool. Accepts any of the options accepted by DBConnection.execute/4."},{"ref":"Arangox.html#request!/6","title":"Arangox.request!/6","type":"function","doc":"Runs a request against a connection pool. Raises in the case of an error. Accepts any of the options accepted by DBConnection.execute!/4."},{"ref":"Arangox.html#start_link/1","title":"Arangox.start_link/1","type":"function","doc":"Starts a connection pool. Options Accepts any of the options accepted by DBConnection.start_link/2, as well as any of the following: :endpoints - A list of ArangoDB endpoints in order of presedence. Each process in a pool will individually attempt to establish a connection with and check the availablility of each endpoint in the order given until one is found. Defaults to [&quot;http://localhost:8529&quot;]. :database - Arangox will prepend /_db/:value to the path of every request that isn&#39;t already prepended. If a value is not given, nothing is prepended (ArangoDB will assume the _system database). :headers - A list of headers to merge with every request. :auth? - Configure whether or not to add an authorization header to every request with the provided username and password. Defaults to true. :username - Defaults to &quot;root&quot;. :password - Defaults to &quot;&quot;. :read_only? - Read-only pools will only connect to followers in an active failover setup and add an x-arango-allow-dirty-read header to every request. Defaults to false. :connect_timeout - Sets the timeout for establishing a connection with a server. :transport_opts - Transport options for the socket interface (which is :gen_tcp or :ssl for both gun and mint, depending on whether or not they are connecting via ssl). :tcp_opts - Transport options for the tcp socket interface (:gen_tcp in the case of gun or mint). :ssl_opts - Transport options for the ssl socket interface (:ssl in the case of gun or mint). :client - A module that implements the Arangox.Client behaviour. Defaults to Arangox.Client.Gun. :client_opts - Options for the client library being used. WARNING: If :transport_opts is set here it will override the options given to :tcp_opts and :ssl_opts. :failover_callback - A function to call every time arangox fails to establish a connection. This is called regardless of whether or not it&#39;s connecting to an endpoint in an active failover setup. Can be either an anonymous function that takes one argument (which is an %Arangox.Error{} struct), or a three-element tuple containing arguments to pass to apply/3 (in which case an %Arangox.Error{} struct is always prepended to the arguments)."},{"ref":"Arangox.html#transaction/3","title":"Arangox.transaction/3","type":"function","doc":"Acquire a connection from a pool and run a series of requests with it. If the connection disconnects, all future calls using that connection reference will fail. Requests can be nested multiple times if the connection reference is used to start a nested transaction (i.e. calling another function that calls this one). The top level transaction function will represent the actual transaction. Delegates to DBConnection.transaction/3. Example {:ok, result} = Arangox.transaction(conn, fn c -&gt; Arangox.request!(c, ...) end)"},{"ref":"Arangox.html#t:body/0","title":"Arangox.body/0","type":"type","doc":""},{"ref":"Arangox.html#t:conn/0","title":"Arangox.conn/0","type":"type","doc":""},{"ref":"Arangox.html#t:endpoint/0","title":"Arangox.endpoint/0","type":"type","doc":""},{"ref":"Arangox.html#t:header/0","title":"Arangox.header/0","type":"type","doc":""},{"ref":"Arangox.html#t:method/0","title":"Arangox.method/0","type":"type","doc":""},{"ref":"Arangox.html#t:path/0","title":"Arangox.path/0","type":"type","doc":""},{"ref":"Arangox.html#t:start_option/0","title":"Arangox.start_option/0","type":"type","doc":""},{"ref":"Arangox.Client.html","title":"Arangox.Client","type":"behaviour","doc":"HTTP client behaviour for Arangox. To use an http library other than :gun or Mint, implement this behaviour in a module and pass that module to the :client start option. Arangox will use that implementation to perform all it&#39;s http related connection and execution operations."},{"ref":"Arangox.Client.html#alive?/1","title":"Arangox.Client.alive?/1","type":"function","doc":""},{"ref":"Arangox.Client.html#c:alive?/1","title":"Arangox.Client.alive?/1","type":"callback","doc":""},{"ref":"Arangox.Client.html#close/1","title":"Arangox.Client.close/1","type":"function","doc":""},{"ref":"Arangox.Client.html#c:close/1","title":"Arangox.Client.close/1","type":"callback","doc":""},{"ref":"Arangox.Client.html#c:connect/2","title":"Arangox.Client.connect/2","type":"callback","doc":"Receives a raw endpoint binary and all the start options from Arangox.start_link/1. The Arangox.Endpoint module has utilities for parsing ArangoDB endpoints. The conn returned from this callback gets placed in the :socket field of an %Arango.Connection{} struct, which represents a connection&#39;s state. It&#39;s up to the client to consolidate the :connect_timeout, :transport_opts and :client_opts options."},{"ref":"Arangox.Client.html#connect/3","title":"Arangox.Client.connect/3","type":"function","doc":""},{"ref":"Arangox.Client.html#request/2","title":"Arangox.Client.request/2","type":"function","doc":""},{"ref":"Arangox.Client.html#c:request/2","title":"Arangox.Client.request/2","type":"callback","doc":"Receives a Arangox.Request struct and a connection&#39;s state, an Arangox.Connection struct, and returns an Arangox.Response struct or error (or exception struct), along with the new state. Arangox handles the encoding and decoding of request and response bodies. In the case of an error, this should return {:error, :noproc, state} if the connection was lost, otherwise an attempt to reconnect won&#39;t be made until the next request hitting this process fails."},{"ref":"Arangox.Client.html#t:conn/0","title":"Arangox.Client.conn/0","type":"type","doc":""},{"ref":"Arangox.Client.html#t:endpoint/0","title":"Arangox.Client.endpoint/0","type":"type","doc":""},{"ref":"Arangox.Client.html#t:exception_or_reason/0","title":"Arangox.Client.exception_or_reason/0","type":"type","doc":""},{"ref":"Arangox.Client.html#t:request/0","title":"Arangox.Client.request/0","type":"type","doc":""},{"ref":"Arangox.Client.html#t:response/0","title":"Arangox.Client.response/0","type":"type","doc":""},{"ref":"Arangox.Client.html#t:start_options/0","title":"Arangox.Client.start_options/0","type":"type","doc":""},{"ref":"Arangox.Client.html#t:state/0","title":"Arangox.Client.state/0","type":"type","doc":""},{"ref":"Arangox.Client.Gun.html","title":"Arangox.Client.Gun","type":"module","doc":"Default HTTP client implementation for arangox. Implements the :gun library. :gun must be present in your deps in order for it to work. documentation hex.pm"},{"ref":"Arangox.Client.Mint.html","title":"Arangox.Client.Mint","type":"module","doc":"An HTTP client implementation for arangox. Implements the Mint library. Add :mint to your deps and pass this module to the :client start option to use it: Arangox.start_link(client: Arangox.Client.Mint) documentation hex.pm"},{"ref":"Arangox.Endpoint.html","title":"Arangox.Endpoint","type":"module","doc":"Utilities for parsing ArangoDB endpoints. See the arangosh or arangojs documentation for examples of supported endpoint formats."},{"ref":"Arangox.Endpoint.html#parse/1","title":"Arangox.Endpoint.parse/1","type":"function","doc":"Parses an endpoint uri and returns a %URI{} struct. This is identical to URI.parse/1 with the exception that the host defaults to localhost and the port to 8529."},{"ref":"Arangox.Endpoint.html#ssl?/1","title":"Arangox.Endpoint.ssl?/1","type":"function","doc":"Determines wether a binary or %URI{} struct is a ssl/tls endpoint."},{"ref":"Arangox.Endpoint.html#unix?/1","title":"Arangox.Endpoint.unix?/1","type":"function","doc":"Determines wether a binary or %URI{} struct is a unix endpoint."},{"ref":"Arangox.Error.html","title":"Arangox.Error","type":"exception","doc":""},{"ref":"Arangox.Error.html#t:t/0","title":"Arangox.Error.t/0","type":"type","doc":""},{"ref":"Arangox.Request.html","title":"Arangox.Request","type":"module","doc":""},{"ref":"Arangox.Request.html#t:t/0","title":"Arangox.Request.t/0","type":"type","doc":""},{"ref":"Arangox.Response.html","title":"Arangox.Response","type":"module","doc":""},{"ref":"Arangox.Response.html#t:t/0","title":"Arangox.Response.t/0","type":"type","doc":""},{"ref":"readme.html","title":"Arangox","type":"extras","doc":"Arangox An implementation of db_connection for ArangoDB, which is silly because ArangoDB is not a transactional database (i.e. no prepare, commit, rollback, etc.), but whatever, it&#39;s a solid connection pooler. Tested on: ArangoDB 3.3.9 - 3.5 Elixir 1.6 - 1.9 OTP 20 - 22 Supports active failover. Peer Dependencies Arangox requires a json library and http client to work, the defaults are :jason and :gun: def deps do [ ... {:arangox, &quot;~&gt; 0.1.0&quot;}, {:jason, &quot;~&gt; 1.1&quot;}, {:gun, &quot;~&gt; 1.3&quot;} ] end You might need to add :gun as an extra application in mix.exs: def application() do [ extra_applications: [:logger, :gun]) ] end To use a different json library, set the :json_library config to the module of your choice: config :arangox, :json_library, Poison Arangox already has a Mint client. To use it, add :mint to your deps instead of :gun and set the :client start option to Arangox.Client.Mint: Arangox.start_link(client: Arangox.Client.Mint) NOTE: Mint does not accept paths to unix sockets at the moment. To use something else, you&#39;d have to implement the Arangox.Client behaviour in a module somewhere and set that instead. The Arangox.Endpoint module has utilities for parsing ArangoDB endpoints. Examples iex&gt; {:ok, conn} = Arangox.start_link(pool_size: 10) iex&gt; Arangox.request(conn, :options, &quot;/&quot;) {:ok, %Arangox.Request{ body: &quot;&quot;, headers: [{&quot;authorization&quot;, &quot;...&quot;}], method: :options, path: &quot;/&quot; }, %Arangox.Response{ body: nil, headers: [ {&quot;x-content-type-options&quot;, &quot;nosniff&quot;}, {&quot;allow&quot;, &quot;DELETE, GET, HEAD, OPTIONS, PATCH, POST, PUT&quot;}, {&quot;server&quot;, &quot;ArangoDB&quot;}, {&quot;connection&quot;, &quot;Keep-Alive&quot;}, {&quot;content-type&quot;, &quot;text/plain; charset=utf-8&quot;}, {&quot;content-length&quot;, &quot;0&quot;} ], status: 200 }} iex&gt; Arangox.options!(conn) %Arangox.Response{ body: nil, headers: [ {&quot;x-content-type-options&quot;, &quot;nosniff&quot;}, {&quot;allow&quot;, &quot;DELETE, GET, HEAD, OPTIONS, PATCH, POST, PUT&quot;}, {&quot;server&quot;, &quot;ArangoDB&quot;}, {&quot;connection&quot;, &quot;Keep-Alive&quot;}, {&quot;content-type&quot;, &quot;text/plain; charset=utf-8&quot;}, {&quot;content-length&quot;, &quot;0&quot;} ], status: 200 }"},{"ref":"readme.html#options","title":"Arangox - Options","type":"extras","doc":"Arangox assumes defaults for the :endpoints, :username and :password options, and db_connection assumes a default :pool_size of 1 so the following: Arangox.start_link() Is equivalent to: options = [ pool_size: 1, endpoints: [&quot;http://localhost:8529&quot;], username: &quot;root&quot;, password: &quot;&quot; ] Arangox.start_link(options) Endpoints See the arangosh or arangojs documentation for examples of supported endpoint formats. As is common amongst ArangoDB drivers, arangox takes a list of endpoints as binaries: endpoints = [ &quot;http://localhost:8529&quot;, &quot;http://localhost:8530&quot;, &quot;http://localhost:8531&quot; ] Arangox.start_link(endpoints: endpoints) Arangox will try to establish a connection with the first endpoint it can and check it&#39;s availability (via the ArangoDB api). If an endpoint is in maintenance mode or is a follower in an active failover setup, it will be skipped. With the read_only? option set to true, arangox will try to find a server in readonly mode instead and add the x-arango-allow-dirty-read header to every request: iex&gt; endpoints = [&quot;http://localhost:8003&quot;, &quot;http://localhost:8004&quot;, &quot;http://localhost:8005&quot;] iex&gt; {:ok, conn} = Arangox.start_link(endpoints: endpoints, read_only?: true) iex&gt; %Arangox.Response{body: body} = Arangox.get!(conn, &quot;/_admin/server/mode&quot;) iex&gt; body[&quot;mode&quot;] &quot;readonly&quot; iex&gt; {:error, exception} = Arangox.post(conn, &quot;/_api/database&quot;, %{name: &quot;newDatabase&quot;}) iex&gt; exception.message &quot;forbidden&quot; Authentication Arangox will generate an authorization header with the :username and :password options and add it to every request. To prevent this behavior, set the :auth? option to false. iex&gt; {:ok, conn} = Arangox.start_link(auth?: false) iex&gt; {:error, exception} = Arangox.get(conn, &quot;/_admin/server/mode&quot;) iex&gt; exception.message &quot;not authorized to execute this request&quot; The header value is obfuscated in transfomed requests returned by arangox, for obvious reasons: iex&gt; {:ok, conn} = Arangox.start_link() iex&gt; {:ok, request, _response} = Arangox.options(conn) iex&gt; request.headers [{&quot;authorization&quot;, &quot;...&quot;}] Databases If a value is given to the :database option, arangox will prepend /_db/:value to the path of every request that isn&#39;t already prepended. If a value is not given, nothing is prepended (ArangoDB will assume the _system database). iex&gt; {:ok, conn} = Arangox.start_link() iex&gt; {:ok, request, _response} = Arangox.get(conn, &quot;/_admin/time&quot;) iex&gt; request.path &quot;/_admin/time&quot; iex&gt; {:ok, conn} = Arangox.start_link(database: &quot;myDatabase&quot;) iex&gt; {:ok, request, _response} = Arangox.get(conn, &quot;/_admin/time&quot;) iex&gt; request.path &quot;/_db/myDatabase/_admin/time&quot; iex&gt; {:ok, request, _response} = Arangox.get(conn, &quot;/_db/anotherDatabase/_admin/time&quot;) iex&gt; request.path &quot;/_db/anotherDatabase/_admin/time&quot; Headers Headers are given as lists of two-element tuples: [{&quot;header&quot;, &quot;value&quot;}, {&quot;another-header&quot;, &quot;another-value&quot;}] When given to the start option they are merged with every request. iex&gt; {:ok, conn} = Arangox.start_link(headers: [{&quot;header&quot;, &quot;value&quot;}]) iex&gt; {:ok, request, _response} = Arangox.options(conn) iex&gt; request.headers [{&quot;authorization&quot;, &quot;...&quot;}, {&quot;header&quot;, &quot;value&quot;}] Headers can also be passed as an argument to any request: iex&gt; {:ok, conn} = Arangox.start_link() iex&gt; {:ok, request, _response} = Arangox.get(conn, &quot;/_admin/time&quot;, [{&quot;header&quot;, &quot;value&quot;}]) iex&gt; request.headers [{&quot;header&quot;, &quot;value&quot;}, {&quot;authorization&quot;, &quot;...&quot;}] Headers given to the start option will not override any of the headers set by Arangox, but headers passed to requests will. Transport Transport options can be specified via :tcp_opts and :ssl_opts, for non-encrypted and encrypted connections respectively. These options are passed directly to the :transport_opts option of :gun or Mint. See :gen_tcp.connect_option() for more information on :tcp_opts, or :ssl.tls_client_option() for :ssl_opts. The :client_opts option can be used to pass client-specific options to :gun or Mint. These options are merged with and may override values set by arangox. Some options cannot be overridden (i.e. Mint&#39;s :mode option). If :transport_opts is set here it will override everything given to :tcp_opts or :ssl_opts, regardless of whether or not a connection is encrypted. See the gun:opts() type in the gun docs or connect/4 in the mint docs for more information."},{"ref":"readme.html#contributing","title":"Arangox - Contributing","type":"extras","doc":"mix do format, credo --strict docker-compose up -d mix test"},{"ref":"readme.html#roadmap","title":"Arangox - Roadmap","type":"extras","doc":"A VelocyStream client An Ecto adapter More descriptive logs If anyone would like to collaborate, find me on the elixir-lang or arangodb-community slack."}]